
<div align="center">
	<h1>Sundate (jalali)</h1>
</div>
<br>

## Installation

**Python 3.6 or newer is required.**  
` pip install sundate `

## Example usage
```PY
    j = gregorian_to_jalali(2020, 5, 17)
    g = jalali_to_gregorian(1399, 2, 28)

    Python3.x:
    print('Jalali: \t', j[0], '/', j[1], '/', j[2])
    print('Gregorian: \t', g[0], '/', g[1], '/', g[2])

```

## Report Bug

 https://discord.gg/tdS45WrK8M
